package Acme::Madness;

use warnings;
use strict;

=head1 NAME

Acme::Madness

our $VERSION = '1.00';

=head1 SYNOPSIS

    use base 'Acme::Madness' ;

=head1 FUNCTIONS

=head2 madness

Inherit from this module to add a some madness to your methods. There
is only a single empty sub called madness.

=cut

sub madness {
}

=head1 AUTHOR

Uri Guttman, C<< <uri at cpan.org> >>

=head1 BUGS

No bugs are possible. No changes will ever be made to this module.

=head1 SUPPORT

No support is available. Use at your own risk.

=head1 ACKNOWLEDGEMENTS

Who would I acknowledge for this?

=head1 COPYRIGHT & LICENSE

Copyright 2008 Uri Guttman, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1; # End of Acme::Madness
